@@ -38,7 +38,8 @@
 
 static const char *network_config_tools[] = {
   "network-admin --configure %i",
-  "redhat-config-network"
+  "redhat-config-network",
+  "system-control-network"
 };
 
 #define UNKNOWN_STR(t,s) G_STMT_START {       \
@@ -74,9 +75,8 @@ typedef struct
   GtkWidget      *inet4_mask_title;
 
   GtkWidget      *dev_frame;
-  GtkWidget      *dev_title;
+  GtkWidget      *dev_type;
   GtkWidget      *dev_addr;
-  GtkWidget      *dev_addr_title;
 
   guint           iface_list_monitor;
   int             n_ifaces;
@@ -255,25 +255,6 @@ netstatus_dialog_update_inet4_support (NetstatusDialogData *data)
     }
 }
 
-static inline void
-set_label_bold (GtkLabel *label)
-{
-  PangoAttribute *bold;
-  PangoAttrList  *attrs;
-
-  attrs = pango_attr_list_new ();
-  bold = pango_attr_weight_new (PANGO_WEIGHT_BOLD);
-  bold->start_index = 0;
-  bold->end_index = G_MAXINT;
-  pango_attr_list_insert (attrs, bold);
-  
-  gtk_label_set_use_markup (label, FALSE);
-  gtk_label_set_use_underline (label, FALSE);
-  gtk_label_set_attributes (label, attrs);
-  
-  pango_attr_list_unref (attrs);
-}
-
 static void
 netstatus_dialog_update_device_support (NetstatusDialogData *data)
 {
@@ -287,8 +268,7 @@ netstatus_dialog_update_device_support (NetstatusDialogData *data)
       gtk_widget_show (data->dev_frame);
 
       /* Device type */
-      gtk_label_set_text (GTK_LABEL (data->dev_title), type);
-      set_label_bold (GTK_LABEL (data->dev_title));
+      gtk_label_set_text (GTK_LABEL (data->dev_type), type);
       
       /* Address */
       if (addr)
@@ -588,10 +568,9 @@ static void
 netstatus_dialog_setup_device_support (NetstatusDialogData *data,
 				       GladeXML            *xml)
 {
-  data->dev_frame       = glade_xml_get_widget (xml, "dev_frame");
-  data->dev_title       = glade_xml_get_widget (xml, "dev_label");
-  data->dev_addr        = glade_xml_get_widget (xml, "dev_addr_label");
-  data->dev_addr_title  = glade_xml_get_widget (xml, "dev_addr_title");
+  data->dev_frame = glade_xml_get_widget (xml, "dev_frame");
+  data->dev_type  = glade_xml_get_widget (xml, "dev_type_label");
+  data->dev_addr  = glade_xml_get_widget (xml, "dev_addr_label");
   
   netstatus_dialog_update_device_support (data);
 }
