@@ -920,39 +920,37 @@ static struct HwType
 #endif
   };
 
-gboolean
-netstatus_iface_get_device_details (NetstatusIface  *iface,
-				    const char     **hw_name,
-				    char           **hw_addr)
+static struct HwType *
+netstatus_iface_get_hw_details (NetstatusIface  *iface,
+				char           **hw_addr)
+				
 {
   static struct HwType *hw_type = NULL;
   struct ifreq          if_req;
   int                   fd;
   int                   i;
 
-  if (hw_name)
-    *hw_name = NULL;
   if (hw_addr)
     *hw_addr = NULL;
-
+  
   if (!iface->priv->name)
-    return FALSE;
+    return NULL;
 
   if ((fd = socket (AF_INET, SOCK_DGRAM, 0)) < 0)
     {
       g_warning (G_STRLOC ": unable to open AF_INET socket: %s\n",
 		 g_strerror (errno));
-      return FALSE;
+      return NULL;
     }
   
   strncpy (if_req.ifr_name, iface->priv->name, IF_NAMESIZE - 1);
   if_req.ifr_name [IF_NAMESIZE - 1] = '\0';
-  if (hw_addr && ioctl (fd, SIOCGIFHWADDR, &if_req) < 0)
+  if (ioctl (fd, SIOCGIFHWADDR, &if_req) < 0)
     {
       g_warning (G_STRLOC ": unable to obtain hardware address: %s\n",
 		 g_strerror (errno));
       close (fd);
-      return FALSE;
+      return NULL;
     }
 
   close (fd);
@@ -968,13 +966,53 @@ netstatus_iface_get_device_details (NetstatusIface  *iface,
     {
       g_warning (G_STRLOC ": no support for hardware type %d\n",
 		 if_req.ifr_hwaddr.sa_family);
-      return FALSE;
+      return NULL;
     }
 
+  if (hw_addr && if_req.ifr_hwaddr.sa_data && hw_type->print_hw_addr)
+    *hw_addr = hw_type->print_hw_addr (if_req.ifr_hwaddr.sa_data);
+
+  return hw_type;
+}
+
+gboolean
+netstatus_iface_get_is_loopback (NetstatusIface *iface)
+{
+  struct HwType *hw_type;
+
+  g_return_val_if_fail (NETSTATUS_IS_IFACE (iface), FALSE);
+
+  if (!(hw_type = netstatus_iface_get_hw_details (iface, NULL)))
+    return FALSE;
+
+#ifdef ARPHRD_LOOPBACK
+  return hw_type->hw_type == ARPHRD_LOOPBACK ? TRUE : FALSE;
+#else
+  return FALSE;
+#endif
+}
+
+gboolean
+netstatus_iface_get_device_details (NetstatusIface  *iface,
+				    const char     **hw_name,
+				    char           **hw_addr)
+{
+  struct HwType *hw_type;
+
+  g_return_val_if_fail (NETSTATUS_IS_IFACE (iface), FALSE);
+
+  if (hw_name)
+    *hw_name = NULL;
+  if (hw_addr)
+    *hw_addr = NULL;
+
+  if (!(hw_type = netstatus_iface_get_hw_details (iface, hw_addr)))
+    return FALSE;
+
+  g_assert (hw_type->hw_name != NULL);
+
   if (hw_name)
     *hw_name = _(hw_type->hw_name);
-  if (hw_addr && if_req.ifr_hwaddr.sa_data && hw_type->print_hw_addr)
-    *hw_addr = hw_type->print_hw_addr (if_req.ifr_hwaddr.sa_data);
 
   return TRUE;
 }
